Struct WpColorRepresentationManagerV1
pub struct WpColorRepresentationManagerV1 { /* private fields */ }wayland and Linux only.Expand description
color representation manager singleton
A singleton global interface used for getting color representation extensions for wl_surface. The extension interfaces allow setting the color representation of surfaces.
Compositors should never remove this global.
See also the Request enum for this interface.
Implementations
impl WpColorRepresentationManagerV1
impl WpColorRepresentationManagerV1
pub fn supported_alpha_mode(&self, alpha_mode: AlphaMode)
pub fn supported_alpha_mode(&self, alpha_mode: AlphaMode)
supported alpha modes
When this object is created, it shall immediately send this event once for each alpha mode the compositor supports.
For the definition of the supported values, see the wp_color_representation_surface_v1::alpha_mode enum.
pub fn supported_coefficients_and_ranges(
&self,
coefficients: Coefficients,
range: Range,
)
pub fn supported_coefficients_and_ranges( &self, coefficients: Coefficients, range: Range, )
supported matrix coefficients and ranges
When this object is created, it shall immediately send this event once for each matrix coefficient and color range combination the compositor supports.
For the definition of the supported values, see the wp_color_representation_surface_v1::coefficients and wp_color_representation_surface_v1::range enums.
pub fn done(&self)
pub fn done(&self)
all features have been sent
This event is sent when all supported features have been sent.